@@ -163,11 +163,13 @@ def dataset(obj: Dict[str, str], tbrn: str, is_delete: bool, yes: bool) -> None:
     cls=DeprecatedOptionsCommand,
     synopsis=(
         "$ gas draft -l tb:<dataset_name>                                # List drafts.",
-        "$ gas draft tb:<dataset_name>[@<branch_name>] [-m <message>]    # Create a draft.",
+        "$ gas draft tb:<dataset_name>[@<branch_name>] [-m <title>]      # Create a draft.",
     ),
 )
 @click.argument("tbrn", type=str)
 @click.option("-l", "--list", "is_list", is_flag=True, help="List the drafts.")
+@click.option("-e", "--edit", is_flag=True, help="Edit the draft's title and description.")
+@click.option("-c", "--close", is_flag=True, help="Close the draft.")
 @click.option(
     "-m",
     "--message",
@@ -176,7 +178,7 @@ def dataset(obj: Dict[str, str], tbrn: str, is_delete: bool, yes: bool) -> None:
     type=str,
     multiple=True,
     default=(),
-    help="The message of the draft.",
+    help="The title of the draft.",
     deprecated=("-t", "--title"),
     preferred="-m",
     since="v1.8.0",
@@ -184,10 +186,12 @@ def dataset(obj: Dict[str, str], tbrn: str, is_delete: bool, yes: bool) -> None:
     cls=DeprecatedOption,
 )
 @click.pass_obj
-def draft(
+def draft(  # pylint: disable=too-many-arguments
     obj: Dict[str, str],
     tbrn: str,
     is_list: bool,
+    edit: bool,
+    close: bool,
     message: Tuple[str, ...],
 ) -> None:
     """List or create drafts.\f
@@ -196,22 +200,22 @@ def draft(
         obj: A dict contains config information.
         tbrn: The tbrn of the dataset.
         is_list: Whether to list the drafts.
+        edit: Whether to edit the draft's title and description.
+        close: Whether to close the draft.
         message: The message of the draft.
 
     """  # noqa: D301,D415
     from .draft import _implement_draft
 
-    _implement_draft(obj, tbrn, is_list, message)
+    _implement_draft(obj, tbrn, is_list, edit, close, message)
 
 
 @command(
-    synopsis=(
-        "$ gas commit tb:<dataset_name>#<draft_number> [-m <message>]      # Commit a draft.",
-    )
+    synopsis=("$ gas commit tb:<dataset_name>#<draft_number> [-m <title>]      # Commit a draft.",)
 )
 @click.argument("tbrn", type=str)
 @click.option(
-    "-m", "--message", type=str, multiple=True, default=(), help="The message of the commit."
+    "-m", "--message", type=str, multiple=True, default=(), help="The title of the commit."
 )
 @click.pass_obj
 def commit(obj: Dict[str, str], tbrn: str, message: Tuple[str, ...]) -> None:
