@@ -12,7 +12,7 @@ from .label import Label
 from .label_box import Box2DSubcatalog, Box3DSubcatalog, LabeledBox2D, LabeledBox3D
 from .label_classification import Classification, ClassificationSubcatalog
 from .label_keypoints import Keypoints2DSubcatalog, LabeledKeypoints2D
-from .label_polygon import LabeledPolygon2D, Polygon2DSubcatalog
+from .label_polygon import LabeledPolygon, PolygonSubcatalog
 from .label_polyline import LabeledPolyline2D, Polyline2DSubcatalog
 from .label_sentence import LabeledSentence, SentenceSubcatalog, Word
 from .supports import CategoryInfo, KeypointsInfo
@@ -32,11 +32,11 @@ __all__ = [
     "LabeledBox2D",
     "LabeledBox3D",
     "LabeledKeypoints2D",
-    "LabeledPolygon2D",
+    "LabeledPolygon",
     "LabeledPolyline2D",
     "LabeledSentence",
     "Items",
-    "Polygon2DSubcatalog",
+    "PolygonSubcatalog",
     "Polyline2DSubcatalog",
     "SentenceSubcatalog",
     "Subcatalogs",
