@@ -33,12 +33,12 @@ class Polyline2DSubcatalog(  # pylint: disable=too-many-ancestors
     Attributes:
         description: The description of the entire 2D polyline subcatalog.
         categories: All the possible categories in the corresponding dataset
-            stored in a :class:`~tensorbay.utility.name.NamedList`
+            stored in a :class:`~tensorbay.utility.name.NameList`
             with the category names as keys
             and the :class:`~tensorbay.label.supports.CategoryInfo` as values.
         category_delimiter: The delimiter in category values indicating parent-child relationship.
         attributes: All the possible attributes in the corresponding dataset
-            stored in a :class:`~tensorbay.utility.name.NamedList`
+            stored in a :class:`~tensorbay.utility.name.NameList`
             with the attribute names as keys
             and the :class:`~tensorbay.label.attribute.AttributeInfo` as values.
         is_tracking: Whether the Subcatalog contains tracking information.
@@ -56,17 +56,17 @@ class Polyline2DSubcatalog(  # pylint: disable=too-many-ancestors
         >>> Polyline2DSubcatalog.loads(catalog["POLYLINE2D"])
         Polyline2DSubcatalog(
           (is_tracking): True,
-          (categories): NamedList [...],
-          (attributes): NamedList [...]
+          (categories): NameList [...],
+          (attributes): NameList [...]
         )
 
         *Initialization Method 2:* Init an empty Polyline2DSubcatalog and then add the attributes.
 
         >>> from tensorbay.label import CategoryInfo, AttributeInfo
-        >>> from tensorbay.utility import NamedList
-        >>> categories = NamedList()
+        >>> from tensorbay.utility import NameList
+        >>> categories = NameList()
         >>> categories.append(CategoryInfo("a"))
-        >>> attributes = NamedList()
+        >>> attributes = NameList()
         >>> attributes.append(AttributeInfo("gender", enum=["female", "male"]))
         >>> polyline2d_subcatalog = Polyline2DSubcatalog()
         >>> polyline2d_subcatalog.is_tracking = True
@@ -75,8 +75,8 @@ class Polyline2DSubcatalog(  # pylint: disable=too-many-ancestors
         >>> polyline2d_subcatalog
         Polyline2DSubcatalog(
           (is_tracking): True,
-          (categories): NamedList [...],
-          (attributes): NamedList [...]
+          (categories): NameList [...],
+          (attributes): NameList [...]
         )
 
     """
