@@ -3,8 +3,7 @@
 # Copyright 2021 Graviti. Licensed under MIT License.
 #
 # pylint: disable=invalid-name
-
-"""Dataloader of the THUCNews dataset."""
+# pylint: disable=missing-module-docstring
 
 import os
 
@@ -16,24 +15,27 @@ DATASET_NAME = "THUCNews"
 
 
 def THUCNews(path: str) -> Dataset:
-    """Dataloader of the THUCNews dataset.
+    """Dataloader of the `THUCNews`_ dataset.
+
+    .. _THUCNews: http://thuctc.thunlp.org/
+
+    The folder structure should be like::
+
+        <path>
+            <category>/
+                0.txt
+                1.txt
+                2.txt
+                3.txt
+                ...
+            <category>/
+            ...
 
     Arguments:
         path: The root directory of the dataset.
-            The folder structure should be like::
-
-                <path>
-                    <category>/
-                        0.txt
-                        1.txt
-                        2.txt
-                        3.txt
-                        ...
-                    <category>/
-                    ...
 
     Returns:
-        Loaded `Dataset` object.
+        Loaded :class:`~tensorbay.dataset.dataset.Dataset` instance.
 
     """
     root_path = os.path.abspath(os.path.expanduser(path))
@@ -41,8 +43,7 @@ def THUCNews(path: str) -> Dataset:
     dataset.load_catalog(os.path.join(os.path.dirname(__file__), "catalog.json"))
     segment = dataset.create_segment()
 
-    categories = dataset.catalog.classification.categories
-    for category in categories:
+    for category in dataset.catalog.classification.categories.keys():
         text_paths = glob(os.path.join(root_path, category, "*.txt"))
         for text_path in text_paths:
             data = Data(text_path)
